=== modified file 'branchview/linegraph.py'
--- branchview/linegraph.py	2008-06-29 15:47:30 +0000
+++ branchview/linegraph.py	2008-05-04 18:16:01 +0000
@@ -12,7 +12,7 @@
 from bzrlib.revision import NULL_REVISION
 from bzrlib.tsort import merge_sort
 
-def linegraph(graph, start_revs, maxnum, broken_line_length = None,
+def linegraph(repository, start_revs, maxnum, broken_line_length = None,
               graph_data = True, mainline_only = False):
     """Produce a directed graph of a bzr repository.
 
@@ -43,6 +43,7 @@
     curved, kinked, etc.) and to pick the actual colours for each index.
     """
     
+    graph = repository.get_graph()
     graph_parents = {}
     ghosts = set()
     graph_children = {}

=== modified file 'branchview/treeview.py'
--- branchview/treeview.py	2008-06-29 15:47:30 +0000
+++ branchview/treeview.py	2008-06-28 15:45:39 +0000
@@ -285,7 +285,7 @@
         show_graph = self.graph_column.get_visible()
 
         self.branch.lock_read()
-        (linegraphdata, index, columns_len) = linegraph(self.branch.repository.get_graph(),
+        (linegraphdata, index, columns_len) = linegraph(self.branch.repository,
                                                         (self.start,) , # Sequence of start revisions
                                                         self.maxnum, 
                                                         broken_line_length,

=== modified file 'revisionview.py'
--- revisionview.py	2008-06-24 10:34:38 +0000
+++ revisionview.py	2008-06-29 19:18:34 +0000
@@ -22,9 +22,11 @@
 import gobject
 import webbrowser
 
-from bzrlib.plugins.gtk import icon_path
 from bzrlib.osutils import format_date
 from bzrlib.util.bencode import bdecode
+from bzrlib.testament import Testament
+
+from bzrlib.plugins.gtk import icon_path
 
 try:
     from bzrlib.plugins.gtk import seahorse
@@ -220,7 +222,17 @@
                                         "This revision has not been signed.")
 
     def show_signature(self, crypttext):
-        key = seahorse.verify(crypttext)
+        (cleartext, key) = seahorse.verify(crypttext)
+
+        assert cleartext is not None
+
+        inv = self.repository.get_inventory(self.revision.revision_id)
+        expected_testament = Testament(self.revision, inv).as_short_text()
+        if expected_testament != cleartext:
+            self.signature_image.set_from_file(icon_path("sign-bad.png"))
+            self.signature_label.set_markup("<b>Signature does not match repository data</b>\n" +
+                        "The signature plaintext is different from the expected testament plaintext.")
+            return
 
         if key and key.is_available():
             if key.is_trusted():
@@ -322,8 +334,8 @@
         self._create_general()
         self._create_relations()
         # Disabled because testaments aren't verified yet:
-        # if has_seahorse:
-        #    self._create_signature()
+        if has_seahorse:
+            self._create_signature()
         self._create_file_info_view()
         self._create_bugs()
 

=== modified file 'seahorse.py'
--- seahorse.py	2008-06-20 03:33:17 +0000
+++ seahorse.py	2008-06-29 19:07:23 +0000
@@ -85,7 +85,10 @@
         if key not in keyset:
             keyset[key] = Key(key)
 
-        return keyset[key]
+        return (cleartext, keyset[key])
+
+    return (cleartext, None)
+
 
 class Key:
 

